#
# spec file for package octave-forge-generate_html
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define octpkg  generate_html
Name:           octave-forge-%{octpkg}
Version:        0.3.3
Release:        1.9
Summary:        Generate HTML web page from help texts
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Math
URL:            http://octave.sourceforge.net
Source0:        http://downloads.sourceforge.net/octave/%{octpkg}-%{version}.tar.gz
BuildArch:      noarch
BuildRequires:  octave-devel
Requires:       makeinfo
Requires:       octave-cli >= 3.2.0

%description
This package provides functions for generating HTML pages that contain
the help texts for a set of functions. The package is designed to be
as general as possible, but also contains convenience functions for
generating a set of pages for entire packages.
This is part of Octave-Forge project.

%prep
%setup -q -c %{name}-%{version}
%octave_pkg_src

%build
%octave_pkg_build

%install
%octave_pkg_install

%check
%octave_pkg_test

%post
%octave --eval "pkg rebuild"

%postun
%octave --eval "pkg rebuild"

%files
%defattr(-,root,root)
%{octpackages_dir}/%{octpkg}-%{version}

%changelog
* Fri May  6 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.3.3:
  * Fix non-cuddling ++ operators to work with Octave >= 7..
  * Dont duplicate demo figures in following non figure demos.
* Fri Aug  7 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.3.2:
  * Fix empty '{}' to work with Octave >= 6.
* Fri Aug 18 2017 badshah400@gmail.com
- Update to version 0.3.1
  * Add lacking information to the informational json file (this
    file is written since version 0.3.0 of generate_html).
- Changes from version 0.3.0:
  * Nested namespaces and classes under namespaces are now handled
  in generating the alphabetical function database.
  * Toplevel functions are now in separate files of the alphabetic
  function database, and in the same directory tree as classes
  and namespaces.
  * Function html helptexts are now in a directory tree
  corresponding to that of the alphabetic function database.
  * Add repository link to index page.
  * In the individual options, as returned by `get_html_options'
  and used in html generation, replacement strings ("%%...") are
  not considered anymore. Instead, options can be anonymous
  functions which use their arguments to configure the output
  string. So if users manually changed options with replacements,
  they have to do it differently now; looking into the
  `get_html_options.m' file will help to figure out the correct
  way.
  * Add Octave Forge stylesheet, icons, and javascript files.
  * Page margins of Octave Forge additional package documentation
  are now configurable with the Octave Forge stylesheet.
* Sat Sep 17 2016 dmitry_r@opensuse.org
- Update to version 0.1.12
  * New option 'older_versions_download'
* Tue Jun  7 2016 dmitry_r@opensuse.org
- Update to version 0.1.11
  * Bugfix release
* Thu Aug 13 2015 dmitry_r@opensuse.org
- Update to version 0.1.9
  * Bugfix release
* Sat May  2 2015 dmitry_r@opensuse.org
- Update to version 0.1.8
  * Bug fixes
  - html_help_text.m, texi2html.m: Fix a bug that was the cause of unmatched
    </p> tags in the HTML output.
  - get_html_options.m: Fix default header (add !DOCTYPE, charset, etc.)
    and Octave Forge header (unordered <ul> </ul> lists are not allowed to be
    nested in <p> </p> blocks).
  * Other changes
  - html_help_text.m: Now entirely based on texi2html.m
  - texi2html.m: Use <dt class="deftypefn"> </dt> blocks both with TexInfo 4.x
    and with TexInfo 5.x.
* Wed Apr  8 2015 dmitry_r@opensuse.org
- Update to version 0.1.7
  * Bug fixes
  - Omit the "News" link if there is no NEWS file, instead of generating an
    error (the NEWS file is optional, according to the manual)
  - Fix broken links on the NEWS, COPYING and overview pages (the link that
    was supposed to point to the index.html of the package)
  - Protect symbols <, > and & by replacing them with the corresponding HTML
    entity (&lt;, &gt; and &amp;) everywhere it makes sense
  - get_txi_files.m: Update the list of ignored *.texi files
  - generate_package_html.m: Let email addresses appear if they exist in
    DESCRIPTION (they were previously hidden because of the < > delimiters)
  - generate_package_html.m: Fix anchor names
  - html_help_text.m: Hide figures only if gnuplot is in use (bug#33180)
  - html_help_text.m: Prevent empty <pre> </pre> blocks (bug#44451)
  * New features
  - Introduce a new %%charset variable for header template, which defaults to
    utf-8 (instead of the hard-coded iso-8859-1 that was previously in use)
  * Documentation
  - Add generate_operators to the INDEX
  - Provide minimal (one-line) help text for generate_html_manual
  * Cleanup
  - Remove obsolete function generate_alphabet
  - Remove unused "docbrowser" style
* Thu Feb 26 2015 dmitry_r@opensuse.org
- Split from octave-forge package, version 0.1.6
